pub struct FixedLengthCodec<const SIZE: usize>;Trait Implementations
Sourceimpl<const SIZE: usize> Clone for FixedLengthCodec<SIZE>
impl<const SIZE: usize> Clone for FixedLengthCodec<SIZE>
Sourcefn clone(&self) -> FixedLengthCodec<SIZE>
fn clone(&self) -> FixedLengthCodec<SIZE>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<const SIZE: usize> Decoder for FixedLengthCodec<SIZE>
impl<const SIZE: usize> Decoder for FixedLengthCodec<SIZE>
Sourcefn decode(
&mut self,
src: &mut BytesMut,
) -> Result<Option<Self::Item>, Self::Error>
fn decode( &mut self, src: &mut BytesMut, ) -> Result<Option<Self::Item>, Self::Error>
Attempts to decode a frame from the provided buffer of bytes. Read more
fn decode_eof(
&mut self,
buf: &mut BytesMut,
) -> Result<Option<Self::Item>, Self::Error>
fn decode_eof( &mut self, buf: &mut BytesMut, ) -> Result<Option<Self::Item>, Self::Error>
A default method available to be called when there are no more bytes
available to be read from the underlying I/O. Read more